@@ -178,12 +178,17 @@ void Messages::processStdoutBuffer (void)
 {
 	const int iLength = m_sStdoutBuffer.lastIndexOf('\n');
 	if (iLength > 0) {
-		const QString& sTemp = m_sStdoutBuffer.left(iLength);
+		QStringListIterator iter(m_sStdoutBuffer.left(iLength).split('\n'));
+		while (iter.hasNext()) {
+			const QString& sTemp = iter.next();
+			if (!sTemp.isEmpty())
+			#if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
+				appendMessagesText(sTemp.trimmed());
+			#else
+				appendMessagesText(sTemp);
+			#endif
+		}
 		m_sStdoutBuffer.remove(0, iLength + 1);
-		QStringList list = sTemp.split('\n');
-		QStringListIterator iter(list);
-		while (iter.hasNext())
-			appendMessagesText(iter.next());
 	}
 }
 
@@ -191,8 +196,14 @@ void Messages::processStdoutBuffer (void)
 // Stdout flusher -- show up any unfinished line...
 void Messages::flushStdoutBuffer (void)
 {
+	processStdoutBuffer();
+
 	if (!m_sStdoutBuffer.isEmpty()) {
-		processStdoutBuffer();
+	#if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
+		appendMessagesText(m_sStdoutBuffer.trimmed());
+	#else
+		appendMessagesText(m_sStdoutBuffer);
+	#endif
 		m_sStdoutBuffer.clear();
 	}
 }
